﻿using System.ComponentModel;
using System.Drawing;
using System.Web;
using Wisej.Core;
using Wisej.Web;

namespace Wisej.StaticContent
{
	public class MyPictureBox : PictureBox, IWisejHandler
	{
		// Hide the property.
		[Browsable(false)]
		[DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
		public new Image Image
		{
			get { return null; }
			set { }
		}

		// Hide the property.
		[Browsable(false)]
		[DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
		public new string ImageSource
		{
			get { return null; }
			set { }
		}

		/// <summary>
		/// Forces the client to reload the image.
		/// </summary>
		public void UpdateImage()
		{
			this._version++;
			base.ImageSource = this.GetPostbackURL() + "&v=" + this._version;

			Update();
		}

		// version counter, necessary to bust the browser cache when the image changes.
		private int _version;

		protected override void OnCreateControl()
		{
			base.OnCreateControl();

			if (((IWisejComponent)this).DesignMode)
			{
				// Set an image to display at design time.
				// base.Image = ...
			}
			else
			{
				base.ImageSource = this.GetPostbackURL();
			}
		}

		bool IWisejHandler.Compress
		{
			get { return false; }
		}

		void IWisejHandler.ProcessRequest(HttpContext context)
		{
			// TODO: Read content from the source: DB, FileSystem, ....
			context.Response.ContentType = "image/png";
			context.Response.WriteFile(Application.MapPath("Images/128x128.png"));
		}
	}
}